@@ -70,10 +70,12 @@ def import_conf():
     """Imports the conf into this module"""
     global conf
     conf = __import__('supybot.conf').conf
+    class Languages(conf.registry.OnlySomeStrings):
+        validStrings = ['de', 'en', 'es', 'fi', 'fr', 'it']
     conf.registerGlobalValue(conf.supybot, 'language',
-        conf.registry.String(currentLocale, """Determines the bot's default
-        language if translations exist. Currently supported are 'de', 'en',
-        'es', 'fi', 'fr' and 'it'."""))
+        Languages(currentLocale, """Determines the bot's default
+        language if translations exist. Currently supported are: %s"""
+        % ', '.join(Languages.validStrings)))
     conf.supybot.language.addCallback(reloadLocalesIfRequired)
 
 def getPluginDir(plugin_name):
@@ -113,7 +115,6 @@ def getLocalePath(name, localeName, extension):
 
 i18nClasses = weakref.WeakValueDictionary()
 internationalizedCommands = weakref.WeakValueDictionary()
-internationalizedFunctions = [] # No need to know their name
 
 def reloadLocalesIfRequired():
     global currentLocale
@@ -124,12 +125,13 @@ def reloadLocalesIfRequired():
         reloadLocales()
 
 def reloadLocales():
+    import supybot.utils as utils
+
     for pluginClass in i18nClasses.values():
         pluginClass.loadLocale()
     for command in list(internationalizedCommands.values()):
         internationalizeDocstring(command)
-    for function in internationalizedFunctions:
-        function.loadLocale()
+    utils.str._relocalizeFunctions(PluginInternationalization())
 
 def normalize(string, removeNewline=False):
     import supybot.utils as utils
@@ -201,7 +203,6 @@ def parse(translationFile):
     return translations
 
 
-i18nSupybot = None
 def PluginInternationalization(name='supybot'):
     # This is a proxy that prevents having several objects for the same plugin
     if name in i18nClasses:
@@ -326,40 +327,6 @@ class _PluginInternationalization:
                 name in self._l10nFunctions:
             return self._l10nFunctions[name]
 
-    def internationalizeFunction(self, name):
-        """Decorates functions and internationalize their code.
-
-        Only useful for Supybot core functions"""
-        if self.name != 'supybot':
-            return
-        class FunctionInternationalizer:
-            def __init__(self, parent, name):
-                self._parent = parent
-                self._name = name
-            def __call__(self, obj):
-                obj = InternationalizedFunction(self._parent, self._name, obj)
-                obj.loadLocale()
-                return obj
-        return FunctionInternationalizer(self, name)
-
-class InternationalizedFunction:
-    """Proxy for functions that need to be fully localized.
-
-    The localization code is in locales/LOCALE.py"""
-    def __init__(self, internationalizer, name, function):
-        self._internationalizer = internationalizer
-        self._name = name
-        self._origin = function
-        internationalizedFunctions.append(self)
-    def loadLocale(self):
-        self.__call__ = self._internationalizer.localizeFunction(self._name)
-        if self.__call__ == None:
-            self.restore()
-    def restore(self):
-        self.__call__ = self._origin
-
-    def __call__(self, *args, **kwargs):
-        return self._origin(*args, **kwargs)
 
 try:
     class InternationalizedString(str):
@@ -375,6 +342,7 @@ except TypeError:
         know if a string is already localized"""
         pass
 
+
 def internationalizeDocstring(obj):
     """Decorates functions and internationalize their docstring.
 
@@ -391,3 +359,13 @@ def internationalizeDocstring(obj):
             # attribute '__doc__' of 'type' objects is not writable
             pass
     return obj
+
+
+def _install():
+    from . import utils
+    _ = PluginInternationalization()
+    utils.gen._ = _
+    utils.str._ = _
+    utils.str._relocalizeFunctions(_)
+
+_install()
